@@ -118,6 +118,17 @@ class TestDBusBindings(unittest.TestCase):
         print "Introspection test passed"
         self.assert_(True)
 
+    def testMultiPathIntrospection(self):
+        # test introspection on an object exported in multiple places
+        # https://bugs.freedesktop.org/show_bug.cgi?id=11794
+        remote_object = self.bus.get_object(NAME, OBJECT + '/Multi1')
+        remote_object.Introspect(dbus_interface="org.freedesktop.DBus.Introspectable")
+        remote_object = self.bus.get_object(NAME, OBJECT + '/Multi2')
+        remote_object.Introspect(dbus_interface="org.freedesktop.DBus.Introspectable")
+        remote_object = self.bus.get_object(NAME, OBJECT + '/Multi2/3')
+        remote_object.Introspect(dbus_interface="org.freedesktop.DBus.Introspectable")
+        self.assert_(True)
+
     def testPythonTypes(self):
         #test sending python types and getting them back
         print "\n********* Testing Python Types ***********"
@@ -356,7 +367,7 @@ class TestDBusBindings(unittest.TestCase):
         for (name, succeed) in test:
             try:
                 print "requesting %s" % name
-                busname = dbus.service.BusName(name)
+                busname = dbus.service.BusName(name, dbus.SessionBus())
             except Exception, e:
                 print "%s:\n%s" % (e.__class__, e)
                 self.assert_(not succeed, 'did not expect registering bus name %s to fail' % name)
@@ -411,19 +422,74 @@ class TestDBusBindings(unittest.TestCase):
     def testFallbackObjectTrivial(self):
         obj = self.bus.get_object(NAME, OBJECT + '/Fallback')
         iface = dbus.Interface(obj, IFACE)
-        path, unique_name = iface.TestPathAndConnKeywords()
+        path, rel, unique_name = iface.TestPathAndConnKeywords()
         self.assertEquals(path, OBJECT + '/Fallback')
-        #self.assertEquals(rel, '/Badger/Mushroom')
+        self.assertEquals(rel, '/')
+        self.assertEquals(unique_name, obj.bus_name)
+
+    def testFallbackObjectNested(self):
+        obj = self.bus.get_object(NAME, OBJECT + '/Fallback/Nested')
+        iface = dbus.Interface(obj, IFACE)
+        path, rel, unique_name = iface.TestPathAndConnKeywords()
+        self.assertEquals(path, OBJECT + '/Fallback/Nested')
+        self.assertEquals(rel, '/')
+        self.assertEquals(unique_name, obj.bus_name)
+
+        obj = self.bus.get_object(NAME, OBJECT + '/Fallback/Nested/Badger/Mushroom')
+        iface = dbus.Interface(obj, IFACE)
+        path, rel, unique_name = iface.TestPathAndConnKeywords()
+        self.assertEquals(path, OBJECT + '/Fallback/Nested/Badger/Mushroom')
+        self.assertEquals(rel, '/Badger/Mushroom')
         self.assertEquals(unique_name, obj.bus_name)
 
     def testFallbackObject(self):
         obj = self.bus.get_object(NAME, OBJECT + '/Fallback/Badger/Mushroom')
         iface = dbus.Interface(obj, IFACE)
-        path, unique_name = iface.TestPathAndConnKeywords()
+        path, rel, unique_name = iface.TestPathAndConnKeywords()
         self.assertEquals(path, OBJECT + '/Fallback/Badger/Mushroom')
-        #self.assertEquals(rel, '/Badger/Mushroom')
+        self.assertEquals(rel, '/Badger/Mushroom')
         self.assertEquals(unique_name, obj.bus_name)
 
+    def testTimeoutSync(self):
+        self.assert_(self.iface.BlockFor500ms(timeout=1.0) is None)
+        self.assertRaises(dbus.DBusException,
+                          lambda: self.iface.BlockFor500ms(timeout=0.25))
+
+    def testTimeoutAsyncClient(self):
+        loop = gobject.MainLoop()
+        passes = []
+        fails = []
+        def correctly_returned():
+            passes.append('1000')
+            if len(passes) + len(fails) >= 2:
+                loop.quit()
+        def correctly_failed(exc):
+            passes.append('250')
+            if len(passes) + len(fails) >= 2:
+                loop.quit()
+        def incorrectly_returned():
+            fails.append('250')
+            if len(passes) + len(fails) >= 2:
+                loop.quit()
+        def incorrectly_failed(exc):
+            fails.append('1000')
+            if len(passes) + len(fails) >= 2:
+                loop.quit()
+        self.iface.BlockFor500ms(timeout=1.0,
+                                 reply_handler=correctly_returned,
+                                 error_handler=incorrectly_failed)
+        self.iface.BlockFor500ms(timeout=0.25,
+                                 reply_handler=incorrectly_returned,
+                                 error_handler=correctly_failed)
+        loop.run()
+        self.assertEquals(passes, ['250', '1000'])
+        self.assertEquals(fails, [])
+
+    def testTimeoutAsyncService(self):
+        self.assert_(self.iface.AsyncWait500ms(timeout=1.0) is None)
+        self.assertRaises(dbus.DBusException,
+                          lambda: self.iface.AsyncWait500ms(timeout=0.25))
+
 """ Remove this for now
 class TestDBusPythonToGLibBindings(unittest.TestCase):
     def setUp(self):
