@@ -22,6 +22,7 @@
 import sys
 import os
 import logging
+from time import sleep
 
 builddir = os.path.normpath(os.environ["DBUS_TOP_BUILDDIR"])
 pydir = os.path.normpath(os.environ["DBUS_TOP_SRCDIR"])
@@ -73,20 +74,21 @@ class TestInterface(dbus.service.Interface):
         return False
 
 class Fallback(dbus.service.FallbackObject):
-    def __init__(self, bus_name, object_path=OBJECT + '/Fallback'):
-        super(Fallback, self).__init__(bus_name, object_path)
+    def __init__(self, conn, object_path=OBJECT + '/Fallback'):
+        super(Fallback, self).__init__(conn, object_path)
+        self.add_to_connection(conn, object_path + '/Nested')
 
-    @dbus.service.method(IFACE, in_signature='', out_signature='os',
-                         path_keyword='path', # rel_path_keyword='rel',
+    @dbus.service.method(IFACE, in_signature='', out_signature='oos',
+                         path_keyword='path', rel_path_keyword='rel',
                          connection_keyword='conn')
-    def TestPathAndConnKeywords(self, path=None, conn=None):
-        return path, conn.get_unique_name()
+    def TestPathAndConnKeywords(self, path=None, conn=None, rel=None):
+        return path, rel, conn.get_unique_name()
 
     @dbus.service.signal(IFACE, signature='s', rel_path_keyword='rel_path')
     def SignalOneString(self, test, rel_path=None):
         logger.info('SignalOneString(%r) @ %r', test, rel_path)
 
-    # Deprecated
+    # Deprecated usage
     @dbus.service.signal(IFACE, signature='ss', path_keyword='path')
     def SignalTwoStrings(self, test, test2, path=None):
         logger.info('SignalTwoStrings(%r, %r) @ %r', test, test2, path)
@@ -110,10 +112,18 @@ class Fallback(dbus.service.FallbackObject):
             logger.info('Emitting %s from abs %r', signal, path)
             sig('I am', 'a deprecated fallback', path=path)
 
+class MultiPathObject(dbus.service.Object):
+    SUPPORTS_MULTIPLE_OBJECT_PATHS = True
+
 class TestObject(dbus.service.Object, TestInterface):
     def __init__(self, bus_name, object_path=OBJECT):
         dbus.service.Object.__init__(self, bus_name, object_path)
         self._removable = RemovableObject()
+        self._multi = MultiPathObject(bus_name, object_path + '/Multi1')
+        self._multi.add_to_connection(bus_name.get_bus(),
+                                      object_path + '/Multi2')
+        self._multi.add_to_connection(bus_name.get_bus(),
+                                      object_path + '/Multi2/3')
 
     """ Echo whatever is sent
     """
@@ -279,6 +289,18 @@ class TestObject(dbus.service.Object, TestInterface):
         # https://bugs.freedesktop.org/show_bug.cgi?id=10174
         return dbus.String('abc'), dbus.Int32(123)
 
+    @dbus.service.method(IFACE, in_signature='', out_signature='')
+    def BlockFor500ms(self):
+        sleep(0.5)
+
+    @dbus.service.method(IFACE, in_signature='', out_signature='',
+                         async_callbacks=('return_cb', 'raise_cb'))
+    def AsyncWait500ms(self, return_cb, raise_cb):
+        def return_from_async_wait():
+            return_cb()
+            return False
+        gobject.timeout_add(500, return_from_async_wait)
+
 session_bus = dbus.SessionBus()
 global_name = dbus.service.BusName(NAME, bus=session_bus)
 object = TestObject(global_name)
